@@ -3,15 +3,7 @@ package Test::Clustericious::Cluster;
 use strict;
 use warnings;
 use 5.010001;
-
-BEGIN {
-  unless($INC{'File/HomeDir/Test.pm'})
-  {
-    eval q{ use File::HomeDir::Test };
-    die $@ if $@;
-  }
-}
-
+use if !$INC{'File/HomeDir/Test.pm'}, 'File::HomeDir::Test';
 use File::HomeDir;
 use Mojo::URL;
 use Mojo::Loader;
@@ -22,7 +14,7 @@ use File::Basename ();
 use File::Path ();
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.31'; # VERSION
+our $VERSION = '0.32'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -52,7 +44,7 @@ sub new
   unshift @$lite_path, ref($args->{lite_path}) ? @{ $args->{lite_path} } : ($args->{lite_path});
   
   bless { 
-    #t           => $t, 
+    t           => $args->{t},
     urls        => [], 
     apps        => [], 
     stopped     => [],
@@ -218,9 +210,44 @@ sub _generate_port
   )->sockport;
 }
 
+sub _create_config_helper
+{
+  my($self) = @_;
+
+  my $helper = sub { return $self };
+        
+  my $class;
+          
+  unless(defined $class)
+  {
+    if(eval q{ require Clustericious::Config::Helpers; 1})
+    {
+      $class = 'Clustericious::Config::Helpers';
+      push @Clustericious::Config::Helpers::EXPORT, 'cluster';
+    }
+    elsif(eval q{ Clustericious::Config::Plugin; 1 })
+    {
+      $class = 'Clustericious::Config::Plugin';
+      push @Clustericious::Config::Plugin::EXPORT, 'cluster';
+    }
+  }
+  
+  return unless $class;
+        
+  do {
+    # there are a multitude of sins here aren't there?
+    no warnings 'redefine';
+    no warnings 'once';
+    no strict 'refs';
+    *{join '::', $class, 'cluster'} = $helper;
+  };
+}
+
 sub create_cluster_ok
 {
   my $self = shift;
+
+  $self->_create_config_helper;
   
   my $total = scalar @_;
   my @urls = map { 
@@ -232,8 +259,6 @@ sub create_cluster_ok
   
   my @errors;
   
-  my $has_clustericious_config = 0;
-  
   my $caller = caller;
   Mojo::Loader::load_class($caller) if $caller ne 'main';
 
@@ -278,37 +303,6 @@ sub create_cluster_ok
         print $fh $config;
         close $fh;
         $config = {};
-        
-        unless($has_clustericious_config)
-        {
-          $has_clustericious_config = 1;
-          my $helper = sub { return $self };
-        
-          state $class;
-          
-          unless(defined $class)
-          {
-            if(eval q{ require Clustericious::Config::Helpers; 1})
-            {
-              $class = 'Clustericious::Config::Helpers';
-              push @Clustericious::Config::Helpers::EXPORT, 'cluster';
-            }
-            else
-            {
-              require Clustericious::Config::Plugin;
-              $class = 'Clustericious::Config::Plugin';
-              push @Clustericious::Config::Plugin::EXPORT, 'cluster';
-            }
-          }
-        
-          do {
-            # there are a multitude of sins here aren't there?
-            no warnings 'redefine';
-            no warnings 'once';
-            no strict 'refs';
-            *{join '::', $class, 'cluster'} = $helper;
-          };
-        }
       }
     }
     else
@@ -375,6 +369,14 @@ sub create_cluster_ok
           { push @errors, [ $app_name, $error ] }
           last;
         }
+        
+        if(-e "$dir/$app_name.psgi")
+        {
+          require Mojolicious;
+          require Mojolicious::Plugin::MountPSGI;
+          $app = Mojolicious->new;
+          $app->plugin('Mojolicious::Plugin::MountPSGI' => { '/' => "$dir/$app_name.psgi" });
+        }
       }
     }
     
@@ -456,11 +458,13 @@ sub create_plugauth_lite_ok
   {
     croak "creat_plugin_lite_ok requires Clustericious 0.9925 or better (see Test::Clustericious::Test for details)";
   }
-  
+
+  my @diag;
+
   if($self->{auth_ua} || $self->{auth_url})
   {
     $ok = 0;
-    $tb->diag("only use create_plugauth_lite_ok once");
+    push @diag, 'only use create_plugauth_lite_ok once';
   }
   else
   {
@@ -483,6 +487,7 @@ sub create_plugauth_lite_ok
   }
   
   $tb->ok($ok, "PlugAuth::Lite instance on " . $self->{auth_url});
+  $tb->diag($_) for @diag;
   
   return $self;
 }
@@ -514,7 +519,7 @@ sub stop_ok
   }
   else
   {
-    $tb->diag("no such app for index: $index");
+    $error = "no such app for index: $index";
     $ok = 0;
   }
   
@@ -536,6 +541,8 @@ sub start_ok
   my $ok = 1;
   my $tb = __PACKAGE__->builder;
   
+  my $error;
+
   my $app = $self->apps->[$index];
   if(defined $app)
   {
@@ -553,7 +560,7 @@ sub start_ok
   }
   else
   {
-    $tb->diag("no such app for index: $index");
+    $error = "no such app for index: $index";
     $ok = 0;
   }
   
@@ -566,7 +573,11 @@ sub start_ok
 
   $test_name //= "start service ($index)";
   
-  $tb->ok($ok, $test_name);
+  my $ret = $tb->ok($ok, $test_name);
+
+  $tb->diag($error) if $error;
+
+  $ret;
 }
 
 
@@ -674,7 +685,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -829,7 +840,7 @@ If not provided, then a new one will be created.
 =head3 lite_path
 
 List reference of paths to search for L<Mojolicious::Lite>
-apps.
+or PSGI apps.
 
 =head1 ATTRIBUTES
 
